%define major 2.54

Name:           keepass
Version:        2.54
Release:        %mkrel 2
License:        GPLv2+
Summary:        Password Manager
Group:          File tools
Url:            https://keepass.info/
Source:         https://downloads.sourceforge.net/keepass/KeePass-%{version}-Source.zip
Source1:        https://downloads.sourceforge.net/keepass/KeePass-%{major}-French.zip
Source2:        https://downloads.sourceforge.net/keepass/KeePass-%{major}-German.zip
Source3:        https://downloads.sourceforge.net/keepass/KeePass-%{major}-Russian.zip
# Upstream does not include a .desktop file, etc..
Patch0:         keepass-desktop-integration.patch
Patch3:         keepass-appdata.patch
# Move XSL files to /usr/share/keepass:
Patch1:         keepass-fix-XSL-search-path.patch
# Locate locally-installed help files:
Patch2:         keepass-enable-local-help.patch
Requires:       mono-winforms
Requires:       xdotool
Requires:       xsel
BuildRequires:  pkgconfig(libgdiplus)
BuildRequires:  imagemagick
BuildRequires:  x11-server-xvfb
BuildRequires:  mono-web
BuildRequires:  mono-devel
BuildRequires:  mono-winforms
ExclusiveArch:  %{mono_arches}
BuildArch:      noarch

%description
KeePass is a free open source password manager, which helps you to manage your
passwords in a secure way. You can put all your passwords in one database,
which is locked with one master key or a key file. So you only have to remember
one single master password or select the key file to unlock the whole database.
The databases are encrypted using the best and most secure encryption
algorithms currently known (AES and Twofish).

%prep
%autosetup -p1 -c

unzip %{SOURCE1}
unzip %{SOURCE2}
unzip %{SOURCE3}

# Work around libpng bug (https://bugzilla.redhat.com/show_bug.cgi?id=1276843):
find -name \*.png -print0 | xargs -0 mogrify -define png:format=png32


%build
( cd Build && sh PrepMonoDev.sh )
find . -name "*.sln" -print -exec sed -i 's/Format Version 10.00/Format Version 11.00/g' {} \;
xbuild /target:KeePass /property:TargetFrameworkVersion=v$(ls -d /usr/lib/mono/*-api | cut -d/ -f5 | cut -d- -f1 | sort -Vr | head -1) /property:Configuration=Release
for subdir in Images_App_HighRes Images_Client_16 Images_Client_HighRes; do
    xvfb-run -a mono Build/KeePass/Release/KeePass.exe -d:`pwd`/Ext/$subdir --makexspfile `pwd`/KeePass/Resources/Data/$subdir.bin
done
xbuild /target:KeePass /property:TargetFrameworkVersion=v$(ls -d /usr/lib/mono/*-api | cut -d/ -f5 | cut -d- -f1 | sort -Vr | head -1) /property:Configuration=Release

%install
install -d \
    %{buildroot}%{_prefix}/lib/%{name} \
    %{buildroot}%{_datadir}/%{name} \
    %{buildroot}%{_datadir}/%{name}/XSL \
    %{buildroot}%{_datadir}/applications \
    %{buildroot}%{_bindir} \
    %{buildroot}%{_datadir}/mime/packages \
    %{buildroot}%{_datadir}/icons/hicolor/512x512/apps \
    %{buildroot}%{_datadir}/icons/hicolor/256x256/apps \
    %{buildroot}%{_datadir}/icons/hicolor/128x128/apps \
    %{buildroot}%{_datadir}/icons/hicolor/64x64/apps \
    %{buildroot}%{_datadir}/icons/hicolor/48x48/apps \
    %{buildroot}%{_datadir}/icons/hicolor/32x32/apps \
    %{buildroot}%{_datadir}/icons/hicolor/16x16/apps \
    %{buildroot}%{_mandir}/man1 \
    %{buildroot}%{_docdir}/%{name} \
    %{buildroot}%{_datadir}/appdata
install -p -m 0644 \
    Build/KeePass/Release/KeePass.exe \
    Ext/KeePass.config.xml \
    Ext/KeePass.exe.config \
    %{buildroot}%{_prefix}/lib/%{name}
install -p -m 0644 \
    Ext/XSL/KDBX_Common.xsl Ext/XSL/KDBX_DetailsFull_HTML.xsl \
    Ext/XSL/KDBX_DetailsLight_HTML.xsl Ext/XSL/KDBX_PasswordsOnly_TXT.xsl \
    Ext/XSL/KDBX_Tabular_HTML.xsl \
    %{buildroot}%{_datadir}/%{name}/XSL
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_512.png \
    %{buildroot}%{_datadir}/icons/hicolor/512x512/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_256.png \
    %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_128.png \
    %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_64.png \
    %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_48.png \
    %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_32.png \
    %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_16.png \
    %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
desktop-file-install --dir=%{buildroot}%{_datadir}/applications dist/%{name}.desktop
install -p -m 0644 dist/%{name}.xml %{buildroot}%{_datadir}/mime/packages
install -p -m 0644 dist/%{name}.1 %{buildroot}%{_mandir}/man1
install -p -m 0644 dist/%{name}.appdata.xml %{buildroot}%{_datadir}/appdata
install -p dist/%{name} %{buildroot}%{_bindir}

sed 's/\r$//' Docs/History.txt > %{buildroot}%{_docdir}/%{name}/History.txt
sed 's/\r$//' Docs/License.txt > %{buildroot}%{_docdir}/%{name}/License.txt

# translations
install -d -m 755 %{buildroot}%{_prefix}/lib/keepass/plugins
install -d -m 755 %{buildroot}%{_prefix}/lib/keepass/Languages
install -m 644 French.lngx  %{buildroot}%{_prefix}/lib/keepass/Languages
install -m 644 German.lngx  %{buildroot}%{_prefix}/lib/keepass/Languages
install -m 644 Russian.lngx  %{buildroot}%{_prefix}/lib/keepass/Languages

%files
%{_docdir}/%{name}
%{_bindir}/%{name}
%{_prefix}/lib/%{name}
%{_datadir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1*


%changelog
* Sat Jun 17 2023 daviddavid <daviddavid> 2.54-2.mga9
+ Revision: 1962290
- add russian and german translations

* Sat Jun 17 2023 daviddavid <daviddavid> 2.54-1.mga9
+ Revision: 1962285
- new version: 2.54, fixes CVE-2023-24055 and CVE-2023-32784 (mga#31935)

* Sun Feb 19 2023 daviddavid <daviddavid> 2.53.1-1.mga9
+ Revision: 1944071
- new version: 2.53.1

* Mon Jan 30 2023 papoteur <papoteur> 2.53-1.mga9
+ Revision: 1936952
- new 2.53

* Tue Aug 23 2022 wally <wally> 2.51-1.mga9
+ Revision: 1879530
- new version 2.51

* Fri Apr 01 2022 umeabot <umeabot> 2.50-2.mga9
+ Revision: 1838692
- Mageia 9 Mass Rebuild

* Wed Jan 26 2022 mrambo3501 <mrambo3501> 2.50-1.mga9
+ Revision: 1769887
- version 2.50
- rediff Patch1

* Sun Apr 18 2021 daviddavid <daviddavid> 2.47-1.mga9
+ Revision: 1716392
- new version: 2.47

* Mon Sep 21 2020 tv <tv> 2.45-3.mga8
+ Revision: 1629212
- rebuild mono fixed mono for proper mono provides & requires...

* Sun Sep 20 2020 tv <tv> 2.45-2.mga8
+ Revision: 1628940
- rebuild for new mono

* Sun May 10 2020 guillomovitch <guillomovitch> 2.45-1.mga8
+ Revision: 1582828
- new version 2.45
+ danf <danf>
- Switch URLs from http: to https:

* Wed Feb 19 2020 umeabot <umeabot> 2.44-2.mga8
+ Revision: 1544568
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 guillomovitch <guillomovitch> 2.44-1.mga8
+ Revision: 1483332
- new version 2.44

* Mon Sep 16 2019 guillomovitch <guillomovitch> 2.43-1.mga8
+ Revision: 1442446
- new version 2.43

* Mon May 06 2019 guillomovitch <guillomovitch> 2.42.1-1.mga7
+ Revision: 1396591
- new version 2.42

* Wed Feb 20 2019 wally <wally> 2.41-3.mga7
+ Revision: 1369001
- rebuild with revived monodevelop

* Sat Jan 12 2019 guillomovitch <guillomovitch> 2.41-2.mga7
+ Revision: 1355461
- add plugins directory

* Sat Jan 12 2019 guillomovitch <guillomovitch> 2.41-1.mga7
+ Revision: 1355456
- new version 2.41

* Thu Sep 20 2018 umeabot <umeabot> 2.40-2.mga7
+ Revision: 1279180
- Mageia 7 Mass Rebuild

* Mon Sep 17 2018 guillomovitch <guillomovitch> 2.40-1.mga7
+ Revision: 1259406
- new version 2.40

* Wed Aug 29 2018 guillomovitch <guillomovitch> 2.39.1-3.mga7
+ Revision: 1255460
- add runtime dependency on xsel

* Thu Jun 07 2018 guillomovitch <guillomovitch> 2.39.1-2.mga7
+ Revision: 1235247
- fix language file location

* Sat May 26 2018 guillomovitch <guillomovitch> 2.39.1-1.mga7
+ Revision: 1232357
- new version 2.39.1

* Sat Jan 13 2018 guillomovitch <guillomovitch> 2.38-1.mga7
+ Revision: 1192519
- new version 2.38

* Sun Oct 15 2017 guillomovitch <guillomovitch> 2.37-1.mga7
+ Revision: 1172090
- new version 2.37

* Fri Aug 04 2017 guillomovitch <guillomovitch> 2.36-2.mga7
+ Revision: 1134992
- get rid of useless devel dependency

* Mon Jul 17 2017 guillomovitch <guillomovitch> 2.36-1.mga7
+ Revision: 1124382
- new version 2.36

* Mon Feb 20 2017 guillomovitch <guillomovitch> 2.35-1.mga6
+ Revision: 1087043
- new version 2.35

* Mon Jul 04 2016 guillomovitch <guillomovitch> 2.34-1.mga6
+ Revision: 1038648
- new version 2.34

* Tue May 17 2016 guillomovitch <guillomovitch> 2.33-1.mga6
+ Revision: 1016566
- new version 2.33

* Wed Mar 23 2016 tv <tv> 2.32-1.mga6
+ Revision: 994283
- new release

* Wed Mar 23 2016 tv <tv> 2.31-2.mga6
+ Revision: 994274
- build fix
- use %%autosetup

* Tue Jan 12 2016 guillomovitch <guillomovitch> 2.31-1.mga6
+ Revision: 922222
- new version 2.31

* Thu Aug 20 2015 guillomovitch <guillomovitch> 2.30-1.mga6
+ Revision: 866989
- new version 2.30

* Tue Jun 23 2015 guillomovitch <guillomovitch> 2.29-1.mga6
+ Revision: 840333
- new version 2.29

* Fri May 22 2015 guillomovitch <guillomovitch> 2.28-3.mga5
+ Revision: 822601
- add french translation file (fix #13553)

* Mon May 18 2015 guillomovitch <guillomovitch> 2.28-2.mga5
+ Revision: 822333
- workaround libgdiplus linking issue by forcing a runtime dependency against the devel subpackage

* Mon Feb 09 2015 guillomovitch <guillomovitch> 2.28-1.mga5
+ Revision: 814448
- new version

* Wed Oct 15 2014 umeabot <umeabot> 2.27-3.mga5
+ Revision: 741750
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.27-2.mga5
+ Revision: 681031
- Mageia 5 Mass Rebuild

* Wed Jul 16 2014 guillomovitch <guillomovitch> 2.27-1.mga5
+ Revision: 653181
- new version 2.27

* Fri Jul 04 2014 guillomovitch <guillomovitch> 2.26-3.mga5
+ Revision: 643102
- add xdotool as runtime dependency, for web form support (#13552)

* Thu Jul 03 2014 guillomovitch <guillomovitch> 2.26-2.mga5
+ Revision: 642755
- fix webdav storage, using debian patch

* Fri May 23 2014 tv <tv> 2.26-1.mga5
+ Revision: 625186
- new release
- new release

* Fri May 23 2014 tv <tv> 2.25-2.mga5
+ Revision: 625115
- rebuild with latest mono in order to try make it work

* Mon Feb 24 2014 guillomovitch <guillomovitch> 2.25-1.mga5
+ Revision: 596606
- new version 2.25

* Fri Feb 21 2014 guillomovitch <guillomovitch> 2.24-1.mga5
+ Revision: 595260
- imported package keepass


* Tue Jan 21 2014 guillomovitch <guillomovitch>  2.24-1.mga4
- first mageia release, using an opensuse spec file
